===============================
networking-plumgrid
===============================

PLUMgrid Open Networking Suite drivers for Neutron

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/networking-plumgrid
* Source: http://git.openstack.org/cgit/openstack/networking-plumgrid
* Bugs: http://bugs.launchpad.net/networking-plumgrid
* PyPI package: https://pypi.python.org/pypi/networking-plumgrid


Config and Installation
-----------------------

For configuration, installation and any other details, please take
a look at the Wiki

::
  http://wiki.openstack.org/PLUMgrid-Neutron

Requirements
------------
* PLUMgrid IOVisor
* PLUMgridLibrary

Supported APIs and API Extensions
---------------------------------
* Networks
* Subnets
* Ports
* External Networks
* Routers
* Security Groups
* Floating IPs
* Quotas
* Port Binding
* Provider Networks
* Extra Route
* Port Bundles
* NAT
* DNS
